@@ -390,7 +390,7 @@ class Web(TestObjectBase):
         self.throwIfDisposed()
         return SnapShotBMPCommand(self).execute(filename)
     
-    def snapShotJPG(self, filename, quality):
+    def snapShotJPG(self, filename, quality = None):
         self.throwIfDisposed()
         return SnapShotJPGCommand(self).execute(filename, quality)
     
